@@ -4,7 +4,7 @@
 Gnuplot for python
 """
 
-import sys, string, types
+import sys, os, string, types
 import collections
 import subprocess
 try:
@@ -123,15 +123,13 @@ class Gnuplot(object):
         self.flush = self.gnuplot.stdin.flush
 
         for v in args:
-            #print v
-            self.__call__('set %s' %(v))
-        # kwargs input:
+            self.cmd('set %s' %(v))
         for k,v in kwargs.items():
-            self[k] = v
-            #print ('set %s %s' %(k, v))
-            self.__call__('set %s %s' %(k, v))
+            #self[k] = v
+            self.cmd('set %s %s' %(k, v))
 
     def __del__(self):
+        #print("%s:%d" %(os.path.basename(__file__), sys._getframe().f_lineno))
         self.close()
 
     def cmd(self, *args):
@@ -158,22 +156,22 @@ class Gnuplot(object):
             self.gnuplot = None
 
     def cd(self, path):
-        self.__call__('cd %s' %(path))
+        self.cmd('cd %s' %(path))
 
     def call(self, filename, *items):
         params = ""
         for item in items:
             params += " " + item
-        self.__call__('call "%s" %s' %(filename, params))
+        self.cmd('call "%s" %s' %(filename, params))
 
     def clear(self):
-        self.__call__('clear')
+        self.cmd('clear')
 
     def do(self, iteration, *commands):
-        self.__call__('do %s {' %(iteration))
+        self.cmd('do %s {' %(iteration))
         for cmd in commands:
-            self.__call__('%s' %(cmd))
-        self.__call__('}')
+            self.cmd('%s' %(cmd))
+        self.cmd('}')
 
     def set(self, *args, **kwargs):
         '''
@@ -182,25 +180,22 @@ class Gnuplot(object):
         '''
         for v in args:
             #print('set %s' %(v))
-            self.__call__('set %s' %(v))
-        # kwargs input:
+            self.cmd('set %s' %(v))
         for k,v in kwargs.items():
-            #print('set %s %s' %(k, v))
-            #self.set(**kwargs)
             if isinstance(v, list):
                 for i in v:
-                    #print('i,v: set %s %s' %(k, i))
-                    self.__call__('set %s %s' %(k, i))
+                    #print('set %s %s' %(k, i))
+                    self.cmd('set %s %s' %(k, i))
             else:
-                #print('k,v: set %s %s' %(k, v))
-                self.__call__('set %s %s' %(k, v))
+                #print('set %s %s' %(k, v))
+                self.cmd('set %s %s' %(k, v))
 
     def unset(self, *items):
         for item in items:
-            self.__call__('unset %s\n' %(item))
+            self.cmd('unset %s\n' %(item))
 
     def reset(self):
-        self.__call__('reset')
+        self.cmd('reset')
 
     def plot(self, *items, **kwargs):
         for k,v in kwargs.items():
@@ -209,16 +204,16 @@ class Gnuplot(object):
             if isinstance(v, list):
                 for i in v:
                     #print('set %s %s' %(k, i))
-                    self.__call__('set %s %s' %(k, i))
+                    self.cmd('set %s %s' %(k, i))
             else:
                 #print('set %s %s' %(k, v))
-                self.__call__('set %s %s' %(k, v))
+                self.cmd('set %s %s' %(k, v))
 
         c = 'plot'
         for item in items:
             c = c + " " + item + ","
         cmd = c.rstrip(',')
-        self.__call__(cmd + '\n')
+        self.cmd(cmd + '\n')
 
     # print function couldn't be compiled.
     #def print(self, *items):
@@ -226,7 +221,7 @@ class Gnuplot(object):
     #    for item in items:
     #        c = c + " " + item + ","
     #    cmd = c.rstrip(',')
-    #    self.__call__(cmd + '\n')
+    #    self.cmd(cmd + '\n')
 
     def splot(self, *items, **kwargs):
         c = 'splot'
@@ -238,44 +233,44 @@ class Gnuplot(object):
             if isinstance(v, list):
                 for i in v:
                     #print('set %s %s' %(k, i))
-                    self.__call__('set %s %s' %(k, i))
+                    self.cmd('set %s %s' %(k, i))
             else:
                 #print('set %s %s' %(k, v))
-                self.__call__('set %s %s' %(k, v))
+                self.cmd('set %s %s' %(k, v))
 
         for item in items:
             c = c + " " + item + ","
         cmd = c.rstrip(',')
-        self.__call__(cmd + '\n')
+        self.cmd(cmd + '\n')
 
 
     def evaluate(self, cmd):
-        self.__call__('evaluate %s' %(cmd))
+        self.cmd('evaluate %s' %(cmd))
 
     def exit(self):
-        self.__call__('exit')
+        self.cmd('exit')
 
     def fit(self, cmd):
         #TODO: to be done.
-        self.__call__('fit %s' %(cmd))
+        self.cmd('fit %s' %(cmd))
 
     def help(self, cmd):
-        self.__call__('help %s\r\n' %(cmd))
+        self.cmd('help %s\r\n' %(cmd))
 
     def history(self, cmd):
-        self.__call__('history %s' %(cmd))
+        self.cmd('history %s' %(cmd))
 
     def load(self, filename):
-        self.__call__('load %s' %(cmd))
+        self.cmd('load %s' %(cmd))
 
     def pause(self, param):
-        self.__call__('pause %s\n' %(param))
+        self.cmd('pause %s\n' %(param))
 
     def __getitem__(self, name): return self.__dict__.get(name.lower(), None)
 
     def __setitem__(self, name, value):
         #print name,value
-        self.__call__('set %s %s\n' %(name, value))
+        self.cmd('set %s %s\n' %(name, value))
 
     def __call__(self, s):
         """Send a command string to gnuplot, followed by newline."""
