@@ -4,8 +4,8 @@
 Gnuplot for python
 """
 
+import sys, os, string, types
 from pygnuplot import gnuplot
-import sys, string, types
 import collections
 import subprocess
 #import numpy as np  
@@ -76,7 +76,6 @@ def multiplot(*args, **kwargs):
                 'xlabel', 'x2label', 'ylabel', 'y2label', 'zlabel', 'cblabel',
                 'xrange', 'x2range', 'yrange', 'y2range', 'zrange', 'cbrange',
                 'rrange', 'trange', 'urange', 'vrange')
-
     g.reset()
 
 def plot(data, *args, **kwargs):
@@ -120,23 +119,42 @@ class Gnuplot(gnuplot.Gnuplot):
 
     """
 
-    def plot(self, *items, **kwargs):
-        for k,v in kwargs.items():
-            #print('set %s %s' %(k, v))
-            self.set(**kwargs)
+    def plot(self, data, *items, **kwargs):
+        self.set(**kwargs)
 
         c = 'plot'
         for item in items:
-            c = c + " " + item + ","
+            c = c + ' "-" ' + item + ","
         cmd = c.rstrip(',')
-        self.__call__(cmd + '\n')
+        self.cmd(cmd + '\n')
+
+        if isinstance(data, pd.DataFrame):
+            content = data.to_csv(sep = ' ')
+        else:
+            content = str(data)
+
+        for item in items:
+            self.__call__(content)
+            self.__call__('e')
+
+    def splot(self, data, *items, **kwargs):
+        for k,v in kwargs.items():
+            self.set(**kwargs)
 
-    def splot(self, *items):
         c = 'splot'
         for item in items:
-            c = c + " " + item + ","
+            c = c + ' "-" ' + item + ","
         cmd = c.rstrip(',')
-        self.__call__(cmd + '\n')
+        self.cmd(cmd + '\n')
+
+        if isinstance(data, pd.DataFrame):
+            content = data.to_csv(sep = ' ')
+        else:
+            content = str(data)
+
+        for item in items:
+            self.__call__(content)
+            self.__call__('e')
 
 if __name__ == '__main__':
     g = Gnuplot()
